# Copyright (c) 2000-2010, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define section   free
%define namedversion   1.0.1

# If you don't want to build with maven, and use straight ant instead,
# give rpmbuild option '--without maven'

%define with_maven %{!?_without_maven:1}%{?_without_maven:0}
%define without_maven %{?_without_maven:1}%{!?_without_maven:0}

Name:           cometd-java-api
Version:        1.0.1
Release:        1%{?dist}
Epoch:          0
Summary:        Cometd Java API
License:        Apache Software License 2.0
Group:          Development/Java
URL:            http://maven.apache.org/
Source0:        cometd-java-%{namedversion}.tar.gz
# svn export http://svn.cometd.com/tags/1.0.1/cometd-java/ cometd-java-1.0.1


#Source1:        %{name}-%{version}-build.xml
Source2:        %{name}-%{version}-jpp-depmap.xml
Source3:        %{name}-%{version}-settings.xml
Source4:        cometd-project.pom
Patch0:         cometd-java-api-pom.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot

BuildArch:      noarch
BuildRequires:  jpackage-utils >= 0:5.0.0
BuildRequires:  java-devel >= 0:1.6.0
BuildRequires:  ant >= 0:1.7.1
%if %{with_maven}
BuildRequires:  maven2-common-poms
BuildRequires:  maven2 >= 0:2.0.8
BuildRequires:  maven2-plugin-ant
BuildRequires:  maven2-plugin-compiler
BuildRequires:  maven2-plugin-install
BuildRequires:  maven2-plugin-jar
BuildRequires:  maven2-plugin-javadoc
BuildRequires:  maven2-plugin-source
BuildRequires:  maven2-plugin-resources
BuildRequires:  maven-surefire-plugin
BuildRequires:  maven-release
BuildRequires:  jakarta-slide-webdavclient
%endif

Requires:  java >= 0:1.6.0

Requires(post):   jpackage-utils >= 0:5.0.0
Requires(postun): jpackage-utils >= 0:5.0.0

%description
Cometd is a scalable HTTP-based event routing bus that uses
a Ajax Push technology pattern known as Comet. The term 
'Comet' was coined by Alex Russell in his post Comet: Low 
Latency Data for the Browser.

The org.cometd java package is intended to be the standard 
java server-side API and implementation for cometd.
Currently there is only the API as a standard component, 
which is implemented by:
* Jetty-6 which provides the current cometd-java 
  implementation. The Jetty-6 release contains the 
  org.mortbay.cometd.continuation.ContinuationCometdServlet 
  class which is written against the Jetty-specific 
  Continuation API, which will run scalably only on the 
  Jetty server.
* Jetty-7 pre-release contains an implementation of the 
  cometd-java API written against the proposed standard 
  servlet-3.0 suspend/resume API. This 
  org.mortbay.cometd.continuation.SuspendingCometdServlet 
  will eventually be the cometd-java implementation and 
  will work on all servlet-3.0 compliant browser.
* Glassfish Grizzly currently has a java implementation of 
  bayeux based on an early version of the dojox.servlet API.
* Tomcat 6 has a prototype working against a modified 
  version of this API 

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%prep
%setup -q -n cometd-java-%{namedversion}
cp %{SOURCE3} settings.xml
sed -i -e "s|<url>__JPP_URL_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
sed -i -e "s|<url>__JAVADIR_PLACEHOLDER__</url>|<url>file://`pwd`/external_repo</url>|g" settings.xml
sed -i -e "s|<url>__MAVENREPO_DIR_PLACEHOLDER__</url>|<url>file://`pwd`/.m2/repository</url>|g" settings.xml
%patch0 -b .sav0

%build
%if %{with_maven}
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p $MAVEN_REPO_LOCAL
mkdir -p $MAVEN_REPO_LOCAL/org/cometd/cometd-project/1.0.1/
cp %{SOURCE4} $MAVEN_REPO_LOCAL/org/cometd/cometd-project/1.0.1/cometd-project-1.0.1.pom

mkdir external_repo
ln -s %{_javadir} external_repo/JPP

export M2_SETTINGS=$(pwd)/settings.xml
    mvn-jpp \
        -e \
        -s $M2_SETTINGS \
        -Dmaven.test.failure.ignore=true \
        -Dmaven2.jpp.depmap.file=%{SOURCE2} \
        -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
        ant:ant install javadoc:javadoc
%else
export CLASSPATH=
#export CLASSPATH=$(build-classpath \
#)
CLASSPATH=$CLASSPATH:target/classes:target/test-classes
ant -Dmaven.settings.offline=true -Dbuild.sysclasspath=only jar javadoc
%endif

%install
rm -rf $RPM_BUILD_ROOT
# jars/poms
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms

%add_to_maven_depmap org.cometd cometd-project %{version} JPP cometd-project
install -m 644 %{SOURCE4} $RPM_BUILD_ROOT/%{_datadir}/maven2/poms/JPP-cometd-project.pom

%add_to_maven_depmap org.cometd.java cometd-java-project %{version} JPP cometd-java-project
install -m 644 pom.xml $RPM_BUILD_ROOT/%{_datadir}/maven2/poms/JPP-cometd-java-project.pom

install -m 644 api/target/cometd-api-%{namedversion}.jar \
               $RPM_BUILD_ROOT%{_javadir}/cometd-api-%{version}.jar
%add_to_maven_depmap org.cometd.java cometd-api %{version} JPP cometd-api
install -m 644 api/pom.xml $RPM_BUILD_ROOT/%{_datadir}/maven2/poms/JPP-cometd-api.pom

(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do ln -sf ${jar} `echo $jar| sed  "s|-%{version}||g"`; done)

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr api/target/site/apidocs/* \
                    $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name} # ghost symlink

%clean
rm -rf $RPM_BUILD_ROOT

%post 
%update_maven_depmap

%postun 
%update_maven_depmap

%files 
%defattr(-,root,root,-)
%{_javadir}/*
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*

%files javadoc
%defattr(-,root,root,-)
%doc %{_javadocdir}/%{name}-%{version}
%doc %{_javadocdir}/%{name}

%changelog
* Sat Sep 18 2010 Ralph Apel <r.apel at r-apel.de> 0:1.0.1-1
- 1.0.1

* Mon Mar 02 2009 Ralph Apel <r.apel at r-apel.de> 0:1.0-0.b4.1jpp
- 1.0-beta4

